# Change Log

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased] - yyyy-mm-dd

### Added

### Changed

### Removed

### Fixed

## [2.0.0] - 2020-09-04

### Added

-   Add public API to get Highlighters for Axis
-   Added onPositionChange event to ChartMarker and SeriesMarker
-   Added more mouse and touch events to chart background
-   layout() method to PublicEngine interface.
-   Add LinearGradientFill and RadialGradientFill fill styles.
-   Added Axis _setTickStrategy_ method.
-   Added AxisTickStrategies.Empty (replaces Axis.setTickStyle( emptyTick ))
-   Added VisibleTicks.setLabelAlignment()
-   Chart3D
-   Axis3D
-   Point3D
-   PointSeries3D
-   PointCloudSeries3D
-   PointStyle3D
-   LineSeries3D
-   PointLineSeries3D

### Changed

-   Refactored thick line rendering.
    -   Improves the visual style of the line when a semi-transparent fill style is used.
    -   Improves GL memory usage. Same line now takes 40 to 70% less GL memory depending on the line.
-   PointSeries now uses faster rendering methods on supported devices.
    -   Major performance improvement
    -   Uses less GL memory
-   columnSpan and rowSpan Dashboard options are now optional and default to 1.
-   Chart options when creating a chart inside dashboard are simplified.
    -   Options are no longer behind a separate object but are instead given in same object as the dashboard options.
-   Reduced zooming animation duration
-   Made transparent backgrounds possible.
-   LightningChart JS now requires the following WebGL extensions to work properly
    -   ANGLE_instanced_arrays
    -   EXT_blend_minmax
    -   OES_element_index_uint
    -   OES_standard_derivatives
    -   OES_vertex_array_object
    -   WEBGL_lose_context
    -   If any of these extensions is missing, then a dismissible warning will be shown to notify users of possibly incorrectly working features.
-   Changed seriesBackground mouse and touch event naming to chartBackground mouse and touch events.
    -   e.g. onSeriesBackgroundMouseDown was changed to onChartBackgroundMouseDown
-   `requestAnimationFrame` and `cancelAnimationFrame` are no longer polyfilled automatically.
    -   The methods should be polyfilled if support for environments where the methods don't exist is needed.
-   Numeric Axis ticks have been reworked
-   DateTime Axis ticks have been reworked
-   Mouse and touch events are properly handled to allow normal browser interactions when chart does no action for the event
-   Changed ColorHEX factory color syntax to follow CSS color syntax, #RRGGBB\[AA\]
-   Changed default highlight behavior of Series.
    -   Series is no longer highlighted by default when hovering over it. Use `series.setHighlightOnHover()` or `chart.setSeriesHighlightOnHover()` to highlight on hover.
-   Improved styles for default themes.

### Removed

-   AxisTickStrategies.NumericWithUnits
-   Passing AxisTickStrategy of default Axes upon creating a ChartXY
-   Passing AxisTickStrategy as parameter of ChartXY.addAxisX() or ChartXY.addAxisY()
-   Removed APIs that were previously marked deprecated.
    -   `Chart.setDataLabelFormater`
    -   `Chart.getDataLabelFormater`
    -   `Chart.setChartBackgroundStroke`
    -   `Chart.getChartBackgroundStroke`
    -   `Series.setMaxPointsCount`
    -   `containerId` option

### Fixed

-   Fix legend box item checkbox looking bad when stroke style is other than 1.
-   Fix touch events triggering outside chart area

## [1.3.1] - 2020-05-29

### Fixed

-   Inconsistent cursor style changing when moving from hovering element to hovering one element to hovering over another element.
-   Fixed a crash when adding data to OHLCSeries
-   Hovering over the Arction logo for long enough caused the chart to freeze itself instead of allowing clicking a link to go to the Arction website.
-   Incorrect resolution and interactions when opening a chart in fullscreen mode

## [1.3.0] - 2020-04-28

### Added

-   Heatmap
-   ChartXY.addHeatmapSeries()
-   IntensityGridSeries can be used for visualization of magnitude in two dimensions.
-   IntensityMeshSeries can be used for visualization of magnitude in two dimensions, where the geometry of the series can be edited.
-   Dashboard.createZoomBandChart()
-   Added Axis _Bands_ and _ConstantLines_.
-   Application/Intranet Deployment key support
-   A way to disable all animations at once.
    -   Call `disableAnimations()` on any chart or specify `disableAnimations: true` as a chart creation option.
-   Added series._addArrayX()_, ._addArrayY()_, ._addArrayXY()_ to basic Series types in XY Charts for user convenience.
    -   These methods cause some overhead when used, so using the series._add()_ is still recommended for best performance.
-   Added _.addArrayY()_ to _OHLCSeriesWithAutomaticPacking_ for user convenience.
    -   This method causes some overhead when used, using _.add()_ method is still recommended for best performance.
-   getSeries() method to XY Charts and Spider chart.
-   Support for rendering in Node JS environment with the help of "@arction/lcjs-headless" package.
-   `renderFrame()` method to engine.
-   Added getDataLabelFillStyle and setDataLabelFillStyle to SolidGauge.

### Changed

-   _FitEngineToDiv.container_ to pass DOM Element to Engine. Users can pass either DOM Element itself, or its ID.
-   Mouse and touch interaction handling to add support for pen and PC touch screen interactions.
    -   All interactions still work the same way, interactions just has better support for more interaction methods.

### Fixed

-   Rendering error on some GPU's where GPU received some vertices as NaN instead of a valid vertex.
-   Inconsistent style for SeriesMarker tick X and Y labels
-   Fixed a TypeError on pyramid chart
-   LightningChart JS logo failing to render correctly when high-dpi mode is used and devicePixelRatio is less than 1
-   LightningChart JS logo duplication in LegendBoxPanel
-   Incorrect cursor styles when hovering over axis or other element with resize cursor style
-   PointSeries.add method requiring added points to be of `ColorPoint` type when `Point` is a valid type for it.

### Deprecated

-   Deprecated use of _FitEngineToDiv.containerId_ in EngineOptions. Use _FitEngineToDiv.container_ instead.
-   Deprecated use of _setChartBackgroundStroke_ in SpiderChart, ChartXY. Use _setChartBackgroundStrokeStyle_ instead.
-   Deprecated use of _getChartBackgroundStroke_ in SpiderChart, ChartXY. Use _getChartBackgroundStrokeStyle_ instead.

## [1.2.2] - 2020-01-07

### Changed

-   Error message when trying to create a chart in container that doesn't exist

### Fixed

-   Mouse interactions permanently disabled when interactions disabled while interaction is in-progress
-   Multiple Slice Explosion restriction not always working

## [1.2.1] - 2019-12-18

### Fixed

-   TypeScript typings duplicate identifier

## [1.2.0] - 2019-12-10

### Added

-   Added Axis _Bands_ and _ConstantLines_.
-   ColorHEX supports format with '0x' prefix.
-   Dashboard.setSplitterStyle()
-   Dashboard.setSplitterStyleHighlight()
-   Dashboard.setBackgroundFillStyle()
-   Dashboard.setBackgroundStrokeStyle()
-   High DPI rendering support with 'devicePixelRatio' engine option
-   Themes, with 'dark' and 'light' preset themes available.
-   LUT (ValueRangePalette)
-   series.getPointAmount() in XY Charts
-   ChartXY.setMouseInteractionsWhileScrolling()
-   ChartXY.setMouseInteractionsWhileZooming()
-   New option when creating lines: highlightThicknessMultiplier can be used to specify thickness of highlighted lines
-   Progressive DataPatterns precision

### Changed

-   Chart examples linked in the readme
-   Mouse interactions are disabled by default when scrolling / zooming. This behavior can be changed with methods in XY Charts.

### Fixed

-   GL errors with Pyramid Chart
-   AutoCursor working incorrectly with touch displays

## [1.1.1] - 2019-10-11

### Changed

-   Chart examples linked in the readme

### Fixed

-   Typo in the readme
-   Missing typings
-   Performance issue found in the trading showcase

## [1.1.0] - 2019-10-03

### Added

-   Dispose API for Charts, Dashboard
-   Add OHLCSeries.set/getFigureAutofitting()

### Changed

-   Removed dependency to crc package.
-   Removed dependency to collections package.

### Deprecated

-   SolidGauge.setDataLabelFormater in favor of SolidGauge.setDataLabelFormatter
-   SolidGauge.getDataLabelFormater in favor of SolidGauge.getDataLabelFormatter
-   OHLCSeries.setMaxPointsCount in favor of OHLCSeries.setMaxPointCount

### Fixed

-   Fixed crash when adding points to step series.
-   PointableTextBox incompatibility with axis custom tick.
-   Empty StrokeStyle not working with Axis Nibs

## [1.0.3] - 2019-08-26

### Added

-   More keywords for npm

### Changed

-   Readme file contents present the package better

## [1.0.1] - 2019-08-14

### Added

-   CHANGELOG.md included in the npm package
-   More keywords for npm

### Fixed

-   Pyramid Chart
    -   Added missing API documentation for `get/setAnimationsEnabled`
-   Funnel Chart
    -   Added missing API documentation for `get/setAnimationsEnabled`

## [1.0.0] - 2019-08-05

### Added

-   2-Dimensional Charts
    -   ChartXY (Cartesian Chart)
        -   Line Series
        -   Point Series
        -   Point Line Series
        -   Spline Series
        -   Step Series
        -   Rectangle Series
        -   Ellipse Series
        -   Box Series
        -   OHLC Series
        -   Area Series (BiPolar, Monopolar, AreaRange)
        -   Axes
    -   Spider Chart
    -   Pie Chart
    -   Gauge Chart
    -   Funnel Chart
    -   Pyramid Chart
-   Markers (for Series / Chart)
-   Cursor
-   Mouse Interactions
-   Touch Support
-   Animations
-   Dashboard
-   LegendBox
-   UI Elements (Buttons, CheckBoxes, Labels, TextBoxes)
